@@ -13,7 +13,7 @@ class UserSerializer(serializers.ModelSerializer):
 
     class Meta:
         model = User
-        fields = ('email', 'first_name', 'last_name',)
+        fields = '__all__'
 
 
 class CreateUserSerializer(serializers.ModelSerializer):
